==> projectx-sdk-1.0.77-20210601.093324-6-sources.jar: cn/com/duiba/projectx/sdk/component/team/dto/TeamInfoResult.java <==
package cn.com.duiba.projectx.sdk.component.team.dto;

public class TeamInfoResult {

    /**
     * 队伍类型
     */
    private String teamType;

    /**
     * 队伍Code
     */
    private String teamCode;

    /**
     * 队伍分数
     */
    private Long teamScore;

    /**
     * 队长userId
     */
    private String leaderUserId;

    /**
     * 队长nickname
     */
    private String leaderNickname;

    /**
     * 队长avatar
     */
    private String leaderAvatar;

    /**
     * 队伍人数
     */
    private Integer memberSize;

    /**
     * 当前队伍人数
     */
    private Integer memberCount;

    /**
     * 是否满员
     */
    private Boolean fullStrength;

    private String extra;

    public String getTeamType() {
        return teamType;
    }

    public void setTeamType(String teamType) {
        this.teamType = teamType;
    }

    public String getTeamCode() {
        return teamCode;
    }

    public void setTeamCode(String teamCode) {
        this.teamCode = teamCode;
    }

    public Long getTeamScore() {
        return teamScore;
    }

    public void setTeamScore(Long teamScore) {
        this.teamScore = teamScore;
    }

    public String getLeaderUserId() {
        return leaderUserId;
    }

    public void setLeaderUserId(String leaderUserId) {
        this.leaderUserId = leaderUserId;
    }

    public String getLeaderNickname() {
        return leaderNickname;
    }

    public void setLeaderNickname(String leaderNickname) {
        this.leaderNickname = leaderNickname;
    }

    public String getLeaderAvatar() {
        return leaderAvatar;
    }

    public void setLeaderAvatar(String leaderAvatar) {
        this.leaderAvatar = leaderAvatar;
    }

    public Integer getMemberSize() {
        return memberSize;
    }

    public void setMemberSize(Integer memberSize) {
        this.memberSize = memberSize;
    }

    public Integer getMemberCount() {
        return memberCount;
    }

    public void setMemberCount(Integer memberCount) {
        this.memberCount = memberCount;
    }

    public Boolean getFullStrength() {
        return fullStrength;
    }

    public void setFullStrength(Boolean fullStrength) {
        this.fullStrength = fullStrength;
    }

    public String getExtra() {
        return extra;
    }

    public void setExtra(String extra) {
        this.extra = extra;
    }
}

==> projectx-sdk-1.0.81-sources.jar: cn/com/duiba/projectx/sdk/component/team/dto/TeamInfoResult.java <==
package cn.com.duiba.projectx.sdk.component.team.dto;

public class TeamInfoResult {

    /**
     * 队伍类型
     */
    private String teamType;

    /**
     * 队伍Code
     */
    private String teamCode;

    /**
     * 队伍分数
     */
    private Long teamScore;

    /**
     * 队长userId
     */
    private String leaderUserId;

    /**
     * 队长nickname
     */
    private String leaderNickname;

    /**
     * 队长avatar
     */
    private String leaderAvatar;

    /**
     * 队伍人数
     */
    private Integer memberSize;

    /**
     * 当前队伍人数
     */
    private Integer memberCount;

    /**
     * 队伍是否满员
     */
    private Boolean fullStrength;

    /**
     * 队伍扩展信息
     */
    private String teamExtra;

    public String getTeamType() {
        return teamType;
    }

    public void setTeamType(String teamType) {
        this.teamType = teamType;
    }

    public String getTeamCode() {
        return teamCode;
    }

    public void setTeamCode(String teamCode) {
        this.teamCode = teamCode;
    }

    public Long getTeamScore() {
        return teamScore;
    }

    public void setTeamScore(Long teamScore) {
        this.teamScore = teamScore;
    }

    public String getLeaderUserId() {
        return leaderUserId;
    }

    public void setLeaderUserId(String leaderUserId) {
        this.leaderUserId = leaderUserId;
    }

    public String getLeaderNickname() {
        return leaderNickname;
    }

    public void setLeaderNickname(String leaderNickname) {
        this.leaderNickname = leaderNickname;
    }

    public String getLeaderAvatar() {
        return leaderAvatar;
    }

    public void setLeaderAvatar(String leaderAvatar) {
        this.leaderAvatar = leaderAvatar;
    }

    public Integer getMemberSize() {
        return memberSize;
    }

    public void setMemberSize(Integer memberSize) {
        this.memberSize = memberSize;
    }

    public Integer getMemberCount() {
        return memberCount;
    }

    public void setMemberCount(Integer memberCount) {
        this.memberCount = memberCount;
    }

    public Boolean getFullStrength() {
        return fullStrength;
    }

    public void setFullStrength(Boolean fullStrength) {
        this.fullStrength = fullStrength;
    }

    public String getTeamExtra() {
        return teamExtra;
    }

    public void setTeamExtra(String teamExtra) {
        this.teamExtra = teamExtra;
    }
}
